@@ -198,7 +198,7 @@ def test_clone_with_url(mock_run):
 @patch(
     "gita.io.parse_clone_config",
     return_value=(
-        {"repo": {"url": "git@github.com:user/repo.git", "path": "/a/repo"}},
+        {"repo": {"url": "git@github.com:user/repo.git", "path": "/a/repo", "flags": []}},
         {},
     ),
 )
@@ -222,7 +222,7 @@ def test_clone_with_config_file(*_):
 @patch(
     "gita.io.parse_clone_config",
     return_value=(
-        {"repo": {"url": "git@github.com:user/repo.git", "path": "/a/repo"}},
+        {"repo": {"url": "git@github.com:user/repo.git", "path": "/a/repo", "flags": []}},
         {},
     ),
 )
